#ifndef NT2_INCLUDE_FUNCTIONS_RANK_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RANK_HPP_INCLUDED

#include <nt2/linalg/include/functions/rank.hpp>

#endif
